@@ -11,7 +11,7 @@ system('clear');
 $| = 1;
 
 my $file = 0;
-my $arg  = join('', @ARGV);
+my $arg  = join(' ', @ARGV);
 my $new_x;
 my $new_y;
 my $F;
@@ -21,15 +21,17 @@ my $image;
 my $angle;
 
 $file = 1 if ($arg =~ /file/i);    # File Handle drawing mode
-if ($arg =~ /(\d+)/) {
-    $dev = $1;
-}
 
 if ($arg =~ /X(\d+)/) {
     $new_x = $1;
+    $arg =~ s/X\d+//;
 }
 if ($arg =~ /Y(\d+)/) {
     $new_y = $1;
+    $arg =~ s/Y\d+//;
+}
+if ($arg =~ /(\d+)/) {
+    $dev = $1;
 }
 
 if (defined($new_x)) {
@@ -172,15 +174,10 @@ while (time < $s) {
               'yy'       => rand($YY),
               'filled'   => 1,
               'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
+                  'colors' => {
+                      'red' => [rand(256),rand(256),rand(256)],
+                      'green' => [rand(256),rand(256),rand(256)],
+                      'blue' => [rand(256),rand(256),rand(256)],
                   }
               }
         }
@@ -199,15 +196,10 @@ while (time < $s) {
               'filled'   => 1,
               'gradient' => {
                   'direction' => 'horizontal',
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
+                  'colors' => {
+                      'red' => [rand(256),rand(256),rand(256)],
+                      'green' => [rand(256),rand(256),rand(256)],
+                      'blue' => [rand(256),rand(256),rand(256)],
                   }
               }
         }
@@ -241,15 +233,10 @@ while (time < $s) {
               'radius'   => rand($XX / 16),
               'filled'   => 1,
               'gradient' => {
-                  'start' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
-                  },
-                  'end' => {
-                      'red'   => rand(256),
-                      'green' => rand(256),
-                      'blue'  => rand(256)
+                  'colors' => {
+                      'red' => [rand(256),rand(256),rand(256)],
+                      'green' => [rand(256),rand(256),rand(256)],
+                      'blue' => [rand(256),rand(256),rand(256)],
                   }
               }
         }
@@ -270,15 +257,10 @@ while (time < $s) {
             'filled'   => 1,
             'gradient' => {
                 'direction' => 'horizontal',
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -310,15 +292,10 @@ while (time < $s) {
             'radius'   => rand($center_y),
             'filled'   => 1,
             'gradient' => {
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -337,15 +314,10 @@ while (time < $s) {
             'filled'   => 1,
             'gradient' => {
                 'direction' => 'horizontal',
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -385,15 +357,10 @@ while (time < $s) {
             'start_degrees' => rand(360),
             'end_degrees'   => rand(360),
             'gradient'      => {
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -426,15 +393,10 @@ while (time < $s) {
             'yradius'  => rand($center_y),
             'filled'   => 1,
             'gradient' => {
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -454,15 +416,10 @@ while (time < $s) {
             'filled'   => 1,
             'gradient' => {
                 'direction' => 'horizontal',
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -492,15 +449,10 @@ while (time < $s) {
             'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],
             'filled'      => 1,
             'gradient'    => {
-                'start' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
-                },
-                'end' => {
-                    'red'   => rand(256),
-                    'green' => rand(256),
-                    'blue'  => rand(256)
+                'colors' => {
+                    'red' => [rand(256),rand(256),rand(256)],
+                    'green' => [rand(256),rand(256),rand(256)],
+                    'blue' => [rand(256),rand(256),rand(256)],
                 }
             }
         }
@@ -680,17 +632,17 @@ $image = $F->load_image(
 $s = time + $factor;
 while (time < $s) {
     $image->{'x'} = abs(rand($XX - $image->{'width'}));
-    $image->{'y'} = abs(rand($YY - $image->{'height'}));
+    $image->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $image->{'height'}));
     $F->blit_write($image);
 }
 
 print_it($F, "Testing Image rotate");
-if ($YY<=192) {
+if ($YY<=240) {
     $image = $F->load_image(
         {
             'x'      => 0,
             'y'      => 0,
-            'width'  => int($YY*.75),
+            'width'  => int($YY*.7),
 #            'height' => int($YY/3),
             'file'   => 'images/RWBY_Oh_No.jpg'
         }
@@ -719,7 +671,7 @@ $angle = 0;
             }
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
-        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
+        $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
 
         $F->blit_write($rot);
 
@@ -740,7 +692,7 @@ $angle = 0;
             }
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
-        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
+        $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
 
         $F->blit_write($rot);
 
@@ -752,10 +704,10 @@ $angle = 0;
 $image = $F->load_image(
     {
         'x'      => 0,
-        'y'      => 0,
+        'y'      => $F->{'Y_CLIP'},
         'width'  => $XX,
-        'height' => $YY,
-        'file'   => 'images/RWBY_Faces.png'
+        'height' => ($YY - $F->{'Y_CLIP'}),
+       'file'   => 'images/RWBY_Faces.png'
     }
 );
 $s = time + $factor;
@@ -769,7 +721,7 @@ while (time < $s) {
             }
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
-        $rot->{'y'} = abs(($YY - $rot->{'height'}) / 2);
+        $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
         print_it($F, "Testing Image flip $dir");
         $F->blit_write($rot);
         sleep .3;
@@ -792,7 +744,7 @@ $image->{'image'} = $F->monochrome({'image' => $image->{'image'}, 'bits' => $F->
 $s = time + $factor;
 while (time < $s) {
     $image->{'x'} = abs(rand($XX - $image->{'width'}));
-    $image->{'y'} = abs(rand($YY - $image->{'height'}));
+    $image->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $image->{'height'}));
     $F->blit_write($image);
 }
 
@@ -805,7 +757,7 @@ while (time < $s) {
         next unless ($info =~ /\.gif$/i);
         foreach my $bench (0 .. 1) {
             for $angle (0 .. 1) {
-                if ($angle || $XX <= 256) {
+                if ($angle || $XX <= 320) {
                     print_it($F, $bench ? "Testing Animated Image Display of '$info' Fullscreen Benchmark" : "Testing Animated Image Display of '$info' Fullscreen");
                     $image = $F->load_image(
                         {
@@ -852,7 +804,7 @@ while (time < $s) {
                         }
                     }
                 }
-                last if ($XX <= 256);
+                last if ($XX <= 320);
             }
         }
     }
@@ -989,7 +941,7 @@ sub print_it {
     $fb->normal_mode();
     $fb->clip_reset();
     $fb->cls();
-    unless ($XX < 256) {
+    unless ($XX < 320) {
         $fb->or_mode();
 
         my $b = $fb->ttf_print(
