@@ -48,7 +48,7 @@ $SIG{'INT'} = sub {
     $SIG{'INT'} = sub {exit(1);};
 };
 
-our @pics : shared;
+our @pics;
 
 my @f;
 foreach my $fb (@fbs) {
@@ -93,7 +93,7 @@ exit(0);
 
 sub gather {
     my $path = shift;
-
+    chop($path) if ($path =~ /\/$/);
     opendir(my $DIR,$path);
     chomp(my @dir = readdir($DIR));
     closedir($DIR);
@@ -106,13 +106,13 @@ sub gather {
             push(@pics,"$path/$file");
         }
     }
-    @pics = shuffle(@pics);
 }
 
 sub show {
     my $FB = shift;
     my $p  = shift;
     my $idx = 0;
+    @pics = shuffle(@pics);
     while ($RUNNING) {
         my $name = $pics[$idx];
         print_it($FB,"Loading image $name");
